@@ -7,7 +7,7 @@ CIp12 <- p12s <- NULL
 ######################################################################################################
 
 
-if(type == "bivariate"){ 
+if(type == "joint"){ 
 
 
 ######
@@ -43,12 +43,17 @@ theta <- x$theta
 
 ######
 
-p1 <- probmS(eta1, x$VC$margins[1])$pr 
-p2 <- probmS(eta2, x$VC$margins[2])$pr  
-  
+p1 <- as.numeric(probmS(eta1, x$VC$margins[1])$pr) 
+p2 <- as.numeric(probmS(eta2, x$VC$margins[2])$pr)  
+theta <- as.numeric(theta)
 ###### 
 
 
+if(cond == 0){
+
+
+if(!(x$BivD %in% x$BivD2)) p12 <- BiCDF(p1, p2, x$nC, theta, 3)
+
 if(x$BivD %in% x$BivD2){
 
 nC1 <- x$VC$ct[which(x$VC$ct[,1] == x$Cop1),2] 
@@ -66,15 +71,71 @@ if(length(theta) > 1)  p12[x$teta.ind2] <- BiCDF(p1[x$teta.ind2], p2[x$teta.ind2
 if(length(theta) == 1) p12[x$teta.ind2] <- BiCDF(p1[x$teta.ind2], p2[x$teta.ind2], nC2, theta, 3)
                          }                            
                                                                            
+           }
+
+
 }
 
 
 
-if(!(x$BivD %in% x$BivD2)) p12 <- BiCDF(p1, p2, x$nC, theta, 3)
 
 
-if(cond == 1) p12 <- p12/p1
-if(cond == 2) p12 <- p12/p2
+
+
+if(cond == 1){
+
+if(!(x$BivD %in% x$BivD2)) p12 <- copgHsCond(p1, p2, theta, dof = 3, x$BivD)$c.copula.be1
+
+
+if(x$BivD %in% x$BivD2){
+
+p12 <- NA
+ 
+if( length(x$teta1) != 0){
+if(length(theta) > 1)  p12[x$teta.ind1] <- copgHsCond(p1[x$teta.ind1], p2[x$teta.ind1], theta[x$teta.ind1], dof = 3, x$Cop1)$c.copula.be1
+if(length(theta) == 1) p12[x$teta.ind1] <- copgHsCond(p1[x$teta.ind1], p2[x$teta.ind1], theta, dof = 3, x$Cop1)$c.copula.be1
+                         }  
+                          
+if( length(x$teta2) != 0){
+if(length(theta) > 1)  p12[x$teta.ind2] <- copgHsCond(p1[x$teta.ind2], p2[x$teta.ind2], theta[x$teta.ind2], dof = 3, x$Cop2)$c.copula.be1
+if(length(theta) == 1) p12[x$teta.ind2] <- copgHsCond(p1[x$teta.ind2], p2[x$teta.ind2], theta, dof = 3, x$Cop2)$c.copula.be1
+                         }                            
+                                                                           
+}
+
+
+
+}
+
+
+
+if(cond == 2){
+
+if(!(x$BivD %in% x$BivD2)) p12 <- copgHsCond(p1, p2, theta, dof = 3, x$BivD)$c.copula.be2
+
+
+if(x$BivD %in% x$BivD2){
+
+p12 <- NA
+ 
+if( length(x$teta1) != 0){
+if(length(theta) > 1)  p12[x$teta.ind1] <- copgHsCond(p1[x$teta.ind1], p2[x$teta.ind1], theta[x$teta.ind1], dof = 3, x$Cop1)$c.copula.be2
+if(length(theta) == 1) p12[x$teta.ind1] <- copgHsCond(p1[x$teta.ind1], p2[x$teta.ind1], theta, dof = 3, x$Cop1)$c.copula.be2
+                         }  
+                          
+if( length(x$teta2) != 0){
+if(length(theta) > 1)  p12[x$teta.ind2] <- copgHsCond(p1[x$teta.ind2], p2[x$teta.ind2], theta[x$teta.ind2], dof = 3, x$Cop2)$c.copula.be2
+if(length(theta) == 1) p12[x$teta.ind2] <- copgHsCond(p1[x$teta.ind2], p2[x$teta.ind2], theta, dof = 3, x$Cop2)$c.copula.be2
+                         }                            
+                                                                           
+}
+
+
+}
+
+
+
+
 
 ############################## 
 
@@ -87,7 +148,6 @@ bs[, mono.sm.pos] <- ifelse(bs[, mono.sm.pos] < 0, 0, bs[, mono.sm.pos])
 
 lf <- length(x$coefficients)
 
-# try with 1 number
                        
 p1s <- probmS( X1%*%t(bs[,1:x$X1.d2])                     , x$VC$margins[1])$pr 
 p2s <- probmS( X2%*%t(bs[,(x$X1.d2+1):(x$X1.d2+x$X2.d2)]) , x$VC$margins[2])$pr
@@ -103,8 +163,13 @@ if( is.null(x$X3) ) est.RHOb <- matrix(rep(est.RHOb, each = dim(p1s)[1]), ncol =
 ###########################   
 
 
+
+if(cond == 0){
+
+
 if(x$VC$BivD %in% c("N","T")) p12s <- matrix(BiCDF(p1s, p2s, x$nC, est.RHOb, 3, test = FALSE), dim(p1s)[1], n.sim) else{
 
+if(!(x$BivD %in% x$BivD2)) p12s <- matrix(BiCDF(p1s, p2s, x$nC, est.RHOb, par2 = 3, test = FALSE), dim(p1s)[1], n.sim)
 
 if(x$BivD %in% x$BivD2){
 
@@ -114,12 +179,55 @@ if( length(x$teta1) != 0) p12s[x$teta.ind1,] <- BiCDF(p1s[x$teta.ind1,], p2s[x$t
 if( length(x$teta2) != 0) p12s[x$teta.ind2,] <- BiCDF(p1s[x$teta.ind2,], p2s[x$teta.ind2,], nC2, -est.RHOb[x$teta.ind2,])
                       
                         }
+      
+ }
+         
+}         
+         
+         
+         
+         
+         
+if(cond == 1){
 
-if(!(x$BivD %in% x$BivD2)) p12s <- BiCDF(p1s, p2s, x$nC, est.RHOb, par2 = 3, test = FALSE)
-                                                                                                                        }
-                                                                               
-if(cond == 1) p12s <- p12s/p1s
-if(cond == 2) p12s <- p12s/p2s
+
+if(!(x$BivD %in% x$BivD2)) p12s <- copgHsCond(p1s, p2s, est.RHOb, dof = 3, x$BivD)$c.copula.be1
+
+if(x$BivD == "T") p12s <- matrix(p12s, dim(p1s)[1], n.sim)
+
+
+if(x$BivD %in% x$BivD2){
+
+p12s <- matrix(NA, ncol = n.sim, nrow = dim(p1s)[1])
+ 
+if( length(x$teta1) != 0) p12s[x$teta.ind1,] <- copgHsCond(p1s[x$teta.ind1,], p2s[x$teta.ind1,],  est.RHOb[x$teta.ind1,], dof = 3, x$Cop1)$c.copula.be1                                               
+if( length(x$teta2) != 0) p12s[x$teta.ind2,] <- copgHsCond(p1s[x$teta.ind2,], p2s[x$teta.ind2,], -est.RHOb[x$teta.ind2,], dof = 3, x$Cop2)$c.copula.be1
+                                                                                                     
+                       }
+
+}
+
+
+
+
+if(cond == 2){
+
+
+if(!(x$BivD %in% x$BivD2)) p12s <- copgHsCond(p1s, p2s, est.RHOb, dof = 3, x$BivD)$c.copula.be2
+
+if(x$BivD == "T") p12s <- matrix(p12s, dim(p1s)[1], n.sim)
+
+
+if(x$BivD %in% x$BivD2){
+
+p12s <- matrix(NA, ncol = n.sim, nrow = dim(p1s)[1])
+ 
+if( length(x$teta1) != 0) p12s[x$teta.ind1,] <- copgHsCond(p1s[x$teta.ind1,], p2s[x$teta.ind1,],  est.RHOb[x$teta.ind1,], dof = 3, x$Cop1)$c.copula.be2                                               
+if( length(x$teta2) != 0) p12s[x$teta.ind2,] <- copgHsCond(p1s[x$teta.ind2,], p2s[x$teta.ind2,], -est.RHOb[x$teta.ind2,], dof = 3, x$Cop2)$c.copula.be2
+                                                                                                     
+                       }
+
+}
 
 
 } # interv
@@ -153,9 +261,8 @@ eta2 <- x$gamlss2$eta1
 }
 
 
-p1 <- probmS(eta1, x$VC$margins[1])$pr 
-p2 <- probmS(eta2, x$VC$margins[2])$pr  
-  
+p1 <- as.numeric(probmS(eta1, x$VC$margins[1])$pr) 
+p2 <- as.numeric(probmS(eta2, x$VC$margins[2])$pr) 
 
 p12 <- p1*p2
 
@@ -191,7 +298,7 @@ if(cond == 2) p12s <- p1s
 } # independence
 
 
-list(p12 = p12, p12s = p12s, p1 = p1, p2 = p2)
+list(p12 = p12, p12s = p12s, p1 = p1, p2 = p2, p3 = NULL)
 
 
 }
